/////////////////////////////////////////////////////////////////////////////
// StandardShader.fx
//
// Copyright (c) 2011, Electronic Arts Inc. All rights reserved.
// Written by David Siems (based on Avery Lee's StandardShader code)
/////////////////////////////////////////////////////////////////////////////
float HalfWidth;
float HalfHeight;

texture  TextureZero;
float UseTextureZero;
sampler BaseSampler = sampler_state
{
    Texture = <TextureZero>;
    AddressU  = CLAMP;
    AddressV  = CLAMP;
    MIPFILTER = NONE;
    MINFILTER = LINEAR;
    MAGFILTER = LINEAR;
};

struct VS_OUT
{
	float4 position   : POSITION0;
	float2 texcoords  : TEXCOORD0;
    float4 color      : COLOR0;
};

VS_OUT VSMain(float2 inPosition : POSITION0,
              float2 inTexture  : TEXCOORD0,
              float4 inColor    : COLOR0)
{
    VS_OUT Out;

    Out.position.xy = (inPosition.xy - float2(0.5f, 0.5f)) / float2(HalfWidth, -HalfHeight) - float2(1.0, -1.0);    
	Out.position.z = 0.0;
	Out.position.w = 1.0;
    
    Out.texcoords = inTexture;
    Out.color = inColor;

	return Out;
}

float4 PSMain(VS_OUT input) : COLOR
{
    float4 result = lerp(input.color, input.color * tex2D(BaseSampler, input.texcoords.xy), UseTextureZero);
    //result.a = input.color.a;
    return result;
}

technique EAWebkitTechnique
{
    pass P0
    {
        AlphaBlendEnable = True;
        DestBlend = InvSrcAlpha;
        SrcBlend = SrcAlpha;
        ZWriteEnable = False;
        ZEnable = False;

        vertexShader = compile vs_2_0 VSMain();
        pixelShader  = compile ps_2_0 PSMain();
    }    
}
